@@ -193,7 +193,7 @@ where
             Err(error) => return Poll::Ready(Err(error)),
         };
 
-        Poll::Ready(Ok(Receiver(channel.split().0)))
+        Poll::Ready(Ok(channel.split().0.into()))
     }
 }
 
@@ -453,7 +453,7 @@ where
             Err(error) => return Poll::Ready(Err(error)),
         };
 
-        Poll::Ready(Ok(Sender(channel.split().1)))
+        Poll::Ready(Ok(channel.split().1))
     }
 }
 
